@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = "0.1"
+__version__ = "0.1.3"
 
 from pymore.equals_tester import EqualsTester
+
+from pymore.iterators import first
